from typing import Dict, Any

from celery import Task
from jsonschema import validate

CODE_INCOMING_DATA_ERROR = 'IncomingDataError'

TASK_SCHEMA = {
    "type": "object",
    "properties": {
        "is_succeed": {"type": "boolean"},
        "msg": {"type": "string"},
        "msg_code": {"type": "string"},
        "data": {},
    },
}


def check_schema(ins: Any) -> None:
    validate(instance=ins, schema=TASK_SCHEMA)


# class FlaskSqlalchemyContext:
#     # debug: from flask import Flask, even import is put here, must be installed first.
#     from flask import Flask
#     from flask_sqlalchemy import SQLAlchemy
#     app_flask: ClassVar[Flask] = Flask(__name__)
#
#     def __new__(cls, url: str, db: SQLAlchemy) -> None:
#         cls.app_flask.config['SQLALCHEMY_DATABASE_URI'] = url
#         db.init_app(cls.app_flask)
#         return cls.app_flask.app_context()


class TaskBase(Task):
    # from flask import Flask
    # from flask_sqlalchemy import SQLAlchemy
    # app_flask: ClassVar[Flask] = Flask(__name__)

    # @classmethod
    # def bind_db(cls, url: str, db: SQLAlchemy) -> None:
    #     """
    #     the method should be called early.
    #     :param url:
    #     :param db:
    #     :return:
    #     """
    #     cls.app_flask.config['SQLALCHEMY_DATABASE_URI'] = url
    #     db.init_app(cls.app_flask)

    @classmethod
    def task_result(cls, data: Dict[str, Any]) -> Dict[str, Any]:
        copied = data.copy()
        copied.setdefault('data', '')
        if copied.get('is_succeed'):
            copied.setdefault('msg', '')
            copied.setdefault('msg_code', '')
        validate(instance=copied, schema=TASK_SCHEMA)
        return data



from __future__ import absolute_import

import traceback
from typing import Dict, Optional, Tuple, Any

from celery import chain
from celery import group
from celery import signature
from nezha.file import Dir
from nezha.uexcel import Excel
from nezha.ustring import is_invalid_str, unique_id
from nezha.errors import IncomingDataError
from nezha.errors import RequestFailed
from muzha.booldata.hz_risk_model import batch_test
from muzha.booldata.multi_platforms_v2 import ApplyDetail
from muzha.booldata.multi_platforms_v2 import LiabilitiesDetails
from muzha.booldata.multi_platforms_v2 import OverdueDetail
from muzha.booldata.multi_platforms_v2 import RepaymentDetail
from muzha.booldata.multi_platforms_v2 import batch_test_apply_detail
from muzha.booldata.multi_platforms_v2 import batch_test_liabilities_detail
from muzha.booldata.multi_platforms_v2 import batch_test_overdue_detail
from muzha.booldata.multi_platforms_v2 import batch_test_repayment_detail
from nezha.file import File

from .celery import app
from .task_notification import send_email_attach, emailAbout, send_dingding_text, dingUrl

"""
celery task batch_test_huizumodel remote call example:

from celery import Celery

app = Celery('async_task')
app.config_from_object('async_task.conf')
app.add_defaults({
    'BROKER_URL': f'redis://{host}:{port}/{db}',
    'CELERY_RESULT_BACKEND': f'redis://{host}:{port}/{db}',
})

if __name__ == '__main__':
    from gitignore.batch_test.mainv3 import BOOLDATA_ACCOUNT
    from pysubway.utils.file import File
    app.send_task('batch_test_huizumodel', (BOOLDATA_ACCOUNT,
                                            'prod',
                                            '01b20490-4a1e-11e9-9eb7-247703d210dc',
                                            'name,phone,idcard\n朱**,180****622,3506261*****511',
                                            File.this_dir(__file__)))
"""


def len_biz_data(biz_data: str) -> int:
    # 1 stands for columns
    return len(biz_data.split('\n')) - 1


def add_header_for_biz_data(biz_data: str, header: Tuple[str, ...] = ('name', 'phone', 'idcard')) -> str:
    """
    header default queue: ('name', 'phone', 'idcard')
    :param biz_data:
    :return:
    """
    return biz_data if biz_data.startswith('name') else '\n'.join((','.join(header),) + (biz_data,))


@app.task(name='batch_test_huizumodel', bind=True, autoretry_for=(RequestFailed,), retry_kwargs={'max_retries': 3})
def batch_test_huizumodel(self: Any, account_info: Dict[str, str],
                          env: str,
                          company_uuid: str,
                          biz_data: str,
                          current_dir: str,
                          raise_failed_exception: bool = True,
                          email_about: Optional[emailAbout] = None,
                          ding_url: Optional[dingUrl] = None) -> Dict:
    """
    :param account_info:
    :param env:
    :param company_uuid:
    :param biz_data:
    :param current_dir:
    :param raise_failed_exception:
    :return:
    """
    from .task_base import TaskBase, CODE_INCOMING_DATA_ERROR
    print('batch_test_huizumodel incoming_data', locals())
    biz_data = add_header_for_biz_data(biz_data)
    if is_invalid_str(biz_data):
        return TaskBase.task_result({'is_succeed': False, 'msg': '提交数据有误'})
    output = File.join_path(current_dir, f'{unique_id()}.xlsx')
    excel_ins = Excel.prepare_file(biz_data).read()
    account = account_info.copy()
    account['company_uuid'] = company_uuid
    error_log = File.join_path(current_dir, 'log', File(output).pure_name)
    try:
        if ding_url:
            print('ding_url is', ding_url)
            ding_url = dingUrl._make(ding_url)
        batch_test(excel_ins.dataframe, account,
                   output, names=tuple(excel_ins.header), error_log=error_log,
                   raise_failed_exception=raise_failed_exception,
                   env=env)
        if not email_about:
            return TaskBase.task_result({'is_succeed': True, 'data': output})
        if email_about:
            email_about = emailAbout._make(email_about)
            send_email_attach.delay(email_about.mail_user,
                                    email_about.mail_pass,
                                    email_about.title,
                                    email_about.content,
                                    output,
                                    email_about.receivers)
            if email_about.specified_receivers:
                send_email_attach.delay(email_about.mail_user,
                                        email_about.mail_pass,
                                        email_about.title,
                                        email_about.content,
                                        output,
                                        email_about.specified_receivers)
        msg = f'{email_about.title}\n{email_about.content}\n测试了{len_biz_data(biz_data)}条.'
        if ding_url:
            send_dingding_text.delay(ding_url.ding_msg, msg)
        return TaskBase.task_result({'is_succeed': True, 'data': output})
    except IncomingDataError as e:
        traceback.print_exc()
        except_info = traceback.format_exc()
        if ding_url:
            send_dingding_text.delay(ding_url.ding_exception, except_info)
        return {'is_succeed': False, 'msg': except_info, 'msg_code': CODE_INCOMING_DATA_ERROR}
    except Exception as e:
        if ding_url:
            send_dingding_text.delay(ding_url.ding_exception, traceback.format_exc())
        traceback.print_exc()
        raise RequestFailed(e)


@app.task(name='multi_v2_batch_test_liabilities_detail', bind=True, autoretry_for=(RequestFailed,),
          retry_kwargs={'max_retries': 3})
def multi_v2_batch_test_liabilities_detail(self: Any, input: str,
                                           input_is_str: bool,
                                           account: Dict[str, str],
                                           output_liabilities_detail: str,
                                           names: Optional[Tuple[str, ...]] = ('name', 'idcard', 'phone'),
                                           raise_failed_exception: bool = True,
                                           error_log: Optional[str] = None) -> None:
    batch_test_liabilities_detail(input,
                                  input_is_str,
                                  account,
                                  output_liabilities_detail,
                                  names=names,
                                  raise_failed_exception=raise_failed_exception,
                                  error_log=error_log)


@app.task(name='multi_v2_batch_test_repayment_detail', bind=True, autoretry_for=(RequestFailed,),
          retry_kwargs={'max_retries': 3})
def multi_v2_batch_test_repayment_detail(self: Any, input: str,
                                         input_is_str: bool,
                                         account: Dict[str, str],
                                         output_repayment_detail: str,
                                         names: Optional[Tuple[str, ...]] = ('name', 'idcard', 'phone'),
                                         raise_failed_exception: bool = True,
                                         error_log: Optional[str] = None) -> None:
    batch_test_repayment_detail(input,
                                input_is_str,
                                account,
                                output_repayment_detail,
                                names=names,
                                raise_failed_exception=raise_failed_exception,
                                error_log=error_log)


@app.task(name='multi_v2_batch_test_overdue_detail', bind=True, autoretry_for=(RequestFailed,),
          retry_kwargs={'max_retries': 3})
def multi_v2_batch_test_overdue_detail(self: Any, input: str,
                                       input_is_str: bool,
                                       account: Dict[str, str],
                                       output_dir_overdue_detail: str,
                                       names: Optional[Tuple[str, ...]] = ('name', 'idcard', 'phone'),
                                       raise_failed_exception: bool = True,
                                       error_log: Optional[str] = None) -> None:
    batch_test_overdue_detail(input,
                              input_is_str,
                              account,
                              output_dir_overdue_detail,
                              names=names,
                              raise_failed_exception=raise_failed_exception,
                              error_log=error_log)


@app.task(name='multi_v2_batch_test_apply_detail', bind=True, autoretry_for=(RequestFailed,),
          retry_kwargs={'max_retries': 3})
def multi_v2_batch_test_apply_detail(self: Any, input: str,
                                     input_is_str: bool,
                                     account: Dict[str, str],
                                     output_dir_apply_detail: str,
                                     names: Optional[Tuple[str, ...]] = ('name', 'idcard', 'phone'),
                                     raise_failed_exception: bool = True,
                                     error_log: Optional[str] = None) -> None:
    batch_test_apply_detail(input,
                            input_is_str,
                            account,
                            output_dir_apply_detail,
                            names=names,
                            raise_failed_exception=raise_failed_exception,
                            error_log=error_log)


@app.task(name='zip_dir', bind=True, autoretry_for=(RequestFailed,), retry_kwargs={'max_retries': 3})
def zip_dir(self: Any, output_dir: str) -> str:
    """

    :param dir:
    :return:
    """
    print('zip_dir', '*' * 10, locals())
    dir = Dir(output_dir)
    return dir.zip()


@app.task(name='async_batch_test_email_notification', bind=True, autoretry_for=(RequestFailed,),
          retry_kwargs={'max_retries': 3})
def async_batch_test_email_notification(self: Any, msg: str,
                                        output: str,
                                        email_about: Optional[emailAbout] = None,
                                        ding_url: Optional[dingUrl] = None) -> None:
    print(f'[async_batch_test_email_notification] local ->{locals()}<-')
    if email_about:
        email_about = emailAbout._make(email_about)
        send_email_attach.delay(email_about.mail_user,
                                email_about.mail_pass,
                                email_about.title,
                                email_about.content,
                                output,
                                email_about.receivers)
        if email_about.specified_receivers:
            send_email_attach.delay(email_about.mail_user,
                                    email_about.mail_pass,
                                    email_about.title,
                                    email_about.content,
                                    output,
                                    email_about.specified_receivers)
    if ding_url:
        ding_url = dingUrl._make(ding_url)
        send_dingding_text.delay(ding_url.ding_msg, msg)


@app.task(name='multi_platforms_v2', bind=True, autoretry_for=(RequestFailed,), retry_kwargs={'max_retries': 3})
def multi_platforms_v2(self: Any,
                       input: str = '',
                       input_is_str: bool = True,
                       account: Optional[Dict[str, str]] = None,
                       output_dir: str = '',
                       names: Optional[Tuple[str, ...]] = ('name', 'idcard', 'phone'),
                       raise_failed_exception: bool = True,
                       error_log: Optional[str] = None,
                       email_about: Optional[emailAbout] = None,
                       ding_url: Optional[dingUrl] = None) -> None:
    print('multi_platforms_v2', locals())
    dir = Dir(output_dir)
    dir.mkdir()
    print('multi_platforms_v2 mkdir', '*' * 10)
    if not dir.is_dir():
        raise ValueError(f'output_dir {output_dir} must be dir')
    input = add_header_for_biz_data(input)
    output_liabilities_detail = File.join_path(output_dir, LiabilitiesDetails.interface_chinese_name + '.xlsx')
    output_repayment_detail = File.join_path(output_dir, RepaymentDetail.interface_chinese_name + '.xlsx')
    output_dir_overdue_detail = File.join_path(output_dir, OverdueDetail.interface_chinese_name + '.xlsx')
    output_dir_apply_detail = File.join_path(output_dir, ApplyDetail.interface_chinese_name + '.xlsx')
    print('multi_platforms_v2 generate files', '*' * 10)
    group_batch_test = group(multi_v2_batch_test_liabilities_detail.si(input,
                                                                       input_is_str,
                                                                       account,
                                                                       output_liabilities_detail,
                                                                       names=names,
                                                                       raise_failed_exception=raise_failed_exception,
                                                                       error_log=error_log),
                             multi_v2_batch_test_repayment_detail.si(input,
                                                                     input_is_str,
                                                                     account,
                                                                     output_repayment_detail,
                                                                     names=names,
                                                                     raise_failed_exception=raise_failed_exception,
                                                                     error_log=error_log),
                             multi_v2_batch_test_overdue_detail.si(input,
                                                                   input_is_str,
                                                                   account,
                                                                   output_dir_overdue_detail,
                                                                   names=names,
                                                                   raise_failed_exception=raise_failed_exception,
                                                                   error_log=error_log),
                             multi_v2_batch_test_apply_detail.si(input,
                                                                 input_is_str,
                                                                 account,
                                                                 output_dir_apply_detail,
                                                                 names=names,
                                                                 raise_failed_exception=raise_failed_exception,
                                                                 error_log=error_log)
                             )
    print('multi_platforms_v2 group_batch_test generate', '*' * 10)
    if email_about:
        email_about = emailAbout._make(email_about)
        msg = f'{email_about.title}\n{email_about.content}\n测试了{len_biz_data(input)}条.'
    else:
        raise ValueError(f'email_about {email_about} not exist')
    chain(signature(group_batch_test),
          zip_dir.si(output_dir),
          async_batch_test_email_notification.si(msg,
                                                 dir.generate_zip_name(),
                                                 email_about=email_about,
                                                 ding_url=ding_url)
          ).delay()
    print('multi_platforms_v2 chain delay', '*' * 10)



from kombu import Exchange
from kombu import Queue
from celery.schedules import crontab


# REDIS_URL = 'redis://*******/10'
CELERY_TIMEZONE = 'Asia/Shanghai'
# BROKER_URL = REDIS_URL
# CELERY_RESULT_BACKEND = REDIS_URL
CELERY_RESULT_SERIALIZER = 'json'
CELERY_TASK_RESULT_EXTENDED = True
CELERY_RESULT_PERSISTENT = True
CELERY_TASK_SERIALIZER = 'json'
CELERY_TASK_RESULT_EXPIRES = None
CELERY_ACCEPT_CONTENT = ['json', 'json']
CELERY_INCLUDE = [
    'blueCup.task_inner_platform',
    'blueCup.task_notification',
    'blueCup.task_xinyan',
    'blueCup.third_interface_bill'
]

CELERY_ROUTES = {
    'blueCup.task_notification.*': {'queue': 'notification'},
}

CELERY_QUEUES = (
    Queue(name='notification', routing_key='task_notification.#',
          exchange=Exchange(name='Exchange_notification', type='topic')),
    Queue(name='third_interface_bill', routing_key='third_interface_bill.#',
          exchange=Exchange(name='Exchange_notification', type='topic')),
)

CELERY_TASK_DEFAULT_QUEUE = 'blueCup'

CELERY_TASK_ANNOTATIONS = {
    'send_email': {'rate_limit': '1/s'},
    'send_email_attach': {'rate_limit': '1/s'},
    'send_dingding_text': {'rate_limit': '1/s'},
    'send_dingding_markdown': {'rate_limit': '1/s'},
}

# corntab
CELERYBEAT_SCHEDULE = {
    'corntab_bill_yesterday_count': {
        'task': 'bill_yesterday_count',
        'schedule': crontab(hour=9, minute=1),
        'args': ()
    },
}




from collections import namedtuple
from typing import Any, Dict

from nezha.aliyun.robot import Robot
from nezha.aliyun.uemail import Email

from .celery import app
from .task_base import check_schema

emailAbout = namedtuple('emailAbout',
                        ['mail_user', 'mail_pass', 'title', 'content', 'filename', 'receivers', 'specified_receivers']
                        )

dingUrl = namedtuple('dingUrl', ['ding_msg', 'ding_exception'])


def check_args(*args: Dict) -> None:
    if len(*args) > 1:
        raise NotImplementedError(f'args {args} is not support now')


@app.task(name='send_email', bind=True, autoretry_for=(Exception,), retry_kwargs={'max_retries': 3})
def send_email(self: Any, mail_user: str,
               mail_pass: str,
               title: str,
               content: str,
               receivers: str,
               content_is_file: bool = False) -> None:
    Email(mail_user, mail_pass).send_email(title, content, receivers, content_is_file=content_is_file)


@app.task(name='send_email_attach', bind=True, autoretry_for=(Exception,), retry_kwargs={'max_retries': 3})
def send_email_attach(self: Any, mail_user: str,
                      mail_pass: str,
                      title: str,
                      content: str,
                      filename: str,
                      receivers: str, *args: Dict) -> None:
    """
    :param self:
    :param mail_user:
    :param mail_pass:
    :param title:
    :param content:
    :param filename: file can get from filename or args.
    :param receivers:
    :param args: It is adapted to celery task flow. the json schema should be TaskBase.schema_response
    :return:
    """
    print('send_email_attach', locals())
    if not filename:
        print('filename may be passed by args, args is', args)
        check_args(*args)
        last_task_result, = args
        check_schema(last_task_result)
        is_succeed = last_task_result.get('is_succeed')
        if not is_succeed:
            raise ValueError(f'last_task_result {last_task_result} is failed')
    Email(mail_user, mail_pass).send_email_attach(title, content, filename, receivers)


@app.task(name='send_dingding_text', bind=True, autoretry_for=(Exception,), retry_kwargs={'max_retries': 3})
def send_dingding_text(self: Any, url: str, msg: str) -> None:
    Robot(url).send_text(msg)


@app.task(name='send_dingding_markdown', bind=True, autoretry_for=(Exception,), retry_kwargs={'max_retries': 3})
def send_dingding_markdown(self: Any, url: str, title: str, msg: str) -> None:
    print('+' * 10, locals())
    Robot(url).send_markdown(title, msg)



"""
REDIS_URL = 'redis://{}:{}/{}'.format('host', 'port', db)
BROKER_URL = REDIS_URL
CELERY_RESULT_BACKEND = SQLALCHEMY_URI

you should run celery like that in command shell:
../venv/bin/python -m pip install celery pymongo jsonschema
../venv/bin/python -m celery -A async_task --loglevel=info worker -b $REDIS_URL ---result-backend xxx
--result-backend $SQLALCHEMY_URL -Q notification,celery
"""

from __future__ import absolute_import

from celery import Celery

app = Celery('blueCup')
app.config_from_object('blueCup.conf')


def generate_celery(broker: str,
                    result_backend: str = '',
                    main: str = 'blueCup',
                    conf: str = 'blueCup.conf') -> Celery:
    result_backend = result_backend or broker
    celery = Celery(main=main)
    celery.config_from_object(conf)
    celery.add_defaults({
        'BROKER_URL': broker,
        'CELERY_RESULT_BACKEND': result_backend,
    })
    return celery



from functools import partial
from typing import Mapping, Any, Callable

import pandas as pd
from muzha.shuhemofang import network_triple_elements as shmf_network_triple_elements
from nezha import umongo
from nezha import utime
from nezha.aliyun.uemail import Email
from nezha.file import File
from nezha.uexcel import to_excel
from nezha.umongo import insert_one, find, find_one
from nezha.utime import strftime

from .celery import app

DB = 'third_interface'
COLLECTION = 'bill'
MONGO_HOST = '47.103.51.193'
MONGO_USERNAME = 'root'
MONGO_PWD = '*******'
_email_info = find_one({'block': 'default'},
                       'email_notification_config',
                       DB,
                       MONGO_HOST,
                       27017,
                       MONGO_USERNAME,
                       MONGO_PWD,
                       'admin')['email_info']
EMAIL = Email(_email_info['mail_user'], _email_info['mail_pass'], _email_info['sender'])
RECEIVERS = _email_info['receiver']
partial_insert_one = partial(insert_one,
                             db=DB,
                             host=MONGO_HOST,
                             port=27017,
                             username=MONGO_USERNAME,
                             password=MONGO_PWD,
                             authSource='admin')

partial_find = partial(find,
                       db=DB,
                       host=MONGO_HOST,
                       port=27017,
                       username=MONGO_USERNAME,
                       password=MONGO_PWD,
                       authSource='admin')


@app.task(name='bill_shuhemofang_network_triple_elements',
          bind=True, autoretry_for=(Exception,),
          retry_kwargs={'max_retries': 3, 'countdown': 1})
def bill_shuhemofang_network_triple_elements(self: Any,
                                             third_interface_name: str,
                                             boolean_order_id: str,
                                             supplier_order_id: str,
                                             supplier_response: Mapping,
                                             biz_data: Mapping,
                                             call_time: str = strftime(),
                                             stored_func: Callable = partial_insert_one,
                                             supplier_uuid: str = 'shuhemofang',
                                             supplier_name: str = '数盒魔方',
                                             product_uuid: str = 'network_triple_elements',
                                             product_name: str = '运营商三要素') -> None:
    product_price = shmf_network_triple_elements.how_much_should_pay(supplier_response)
    supplier_status = True if product_price else False
    data = locals().copy()
    list(map(lambda x: data.pop(x), ('self', 'stored_func')))
    stored_func(data)


@app.task(name='bill_yesterday_count',
          bind=True, autoretry_for=(Exception,),
          retry_kwargs={'max_retries': 3, 'countdown': 1})
def bill_yesterday_count(self: Any):
    all_iter = partial_find({'call_time': umongo.yesterday}, 'bill')
    result = []
    for one_record in all_iter:
        if isinstance(one_record, dict):
            not_display_keys = {'_id', 'supplier_response', 'supplier_uuid', 'product_uuid', 'third_interface_name'}
            tuple(map(lambda key: one_record.get(key) and one_record.pop(key), not_display_keys))
            result.append(one_record)
        else:
            print(f'one_record {one_record} is unexpected')
    p_columns = {
        'boolean_order_id': '布尔订单号',
        'call_time': '调用时间',
        'product_name': '产品名称',
        'product_price': '产品单价',
        'supplier_name': '供应商名称',
        'supplier_order_id': '供应商订单号',
        'supplier_status': '状态',
    }
    p_header = ('布尔订单号', '供应商订单号', '供应商名称', '产品名称', '产品单价', '调用时间', '状态')
    df = pd.DataFrame(result, columns=p_columns)
    df.rename(columns=p_columns, inplace=True)
    yesterday = utime.yesterday(precision="day")
    xlsx = File.join_path(File.this_dir(__file__), f'{yesterday}.xlsx')
    to_excel(df, xlsx, columns=p_header)
    EMAIL.send_email_attach(f'{yesterday} 供应商调用统计', '', xlsx, RECEIVERS)


if __name__ == '__main__':
    bill_yesterday_count()



# !/usr/bin/env python
# coding: utf-8

from setuptools import find_packages
from setuptools import setup

install_requires = [
    'celery',
    'jsonschema',
    'nezha',
    'muzha',
    'pandas',
    'pymongo',
    'redis',
    'flower'
]

setup(
    name='blueCup',
    version='0.0.11',
    author='kougazhang',
    author_email='kougazhang@gmail.com',
    url='https://github.com/kougazhang',
    description="Little blue cup, who do not love?",
    packages=find_packages(),
    install_requires=install_requires,
)



from typing import Any, Dict

from .celery import app


@app.task(name='async_xinyan_overdue_main', bind=True, autoretry_for=(Exception,),
          retry_kwargs={'max_retries': 3, 'countdown': 1})
def async_xinyan_overdue_main(self: Any, idcard: str,
                              id_name: str,
                              private_key_path: str,
                              url: str = 'https://api.xinyan.com/product/archive/v3/overdue',
                              phone_no: str = '',
                              bankcard_no: str = '',
                              member_id: str = '',
                              terminal_id: str = '') -> Dict:
    from muzha.xinyan.base import xinyan_overdue_main

    return xinyan_overdue_main(idcard,
                               id_name,
                               private_key_path,
                               url=url,
                               phone_no=phone_no,
                               bankcard_no=bankcard_no,
                               member_id=member_id,
                               terminal_id=terminal_id)


@app.task(name='async_xinyan_radar_main', bind=True, autoretry_for=(Exception,),
          retry_kwargs={'max_retries': 3, 'countdown': 1})
def async_xinyan_radar_main(self: Any, idcard: str,
                            id_name: str,
                            private_key_path: str,
                            url: str = 'https://api.xinyan.com/product/radar/v3/apply',
                            phone_no: str = '',
                            bankcard_no: str = '',
                            member_id: str = '',
                            terminal_id: str = '') -> Dict:
    from muzha.xinyan.base import xinyan_radar_main
    return xinyan_radar_main(idcard,
                             id_name,
                             private_key_path,
                             url=url,
                             phone_no=phone_no,
                             bankcard_no=bankcard_no,
                             member_id=member_id,
                             terminal_id=terminal_id)
